# Security Policy

## Supported Versions

| Version  | Supported          |
| -------  | ------------------ |
| >=0.12.0 | :white_check_mark: |

Until we reach a 1.0 milestone, we will generally only support the latest
release of the project. If you are having issues with an older version, please
upgrade to the latest version and see if the issue is resolved. If not, please
open an Issue.

If the latest full release does not help, try the latest alpha or beta version
(if available) to see if that fixes the issue. If not, please open an Issue.

## Reporting a Vulnerability

If you find a security vulnerability in this code, [please open an
Issue](https://github.com/seapagan/lice2/issues) and report it.
It may be already known to us and we may be working on a fix. If not, we will
work with you to understand the issue and fix it. Generally we would annouce any
known vulnerability in the
[Discussions](https://github.com/seapagan/lice2/discussions)
forum.

We use **Dependabot** for security updates and dependency management. If a
security vulnerability is found in a dependency, Dependabot will issue a PR to
fix this as soon as an updated version of the dependency is available. We will
merge these PRs as soon as they are available.

Note that this code is provided as-is, and is not guaranteed to be
suitable for any purpose.  Use at your own risk.
